@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,9 +33,10 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api import httpbody_pb2  # type: ignore
 from google.protobuf import any_pb2  # type: ignore
-from .transports.base import GatewayServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import GatewayServiceGrpcAsyncIOTransport
+
 from .client import GatewayServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, GatewayServiceTransport
+from .transports.grpc_asyncio import GatewayServiceGrpcAsyncIOTransport
 
 
 class GatewayServiceAsyncClient:
@@ -217,21 +218,21 @@ class GatewayServiceAsyncClient:
         r"""GetResource performs an HTTP GET request on the
         Kubernetes API Server.
 
-
         .. code-block:: python
 
+            from google.api import httpbody_pb2  # type: ignore
             from google.cloud.gkeconnect import gateway_v1beta1
 
-            def sample_get_resource():
+            async def sample_get_resource():
                 # Create a client
-                client = gateway_v1beta1.GatewayServiceClient()
+                client = gateway_v1beta1.GatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
-                request = gateway_v1beta1.HttpBody(
+                request = httpbody_pb2.HttpBody(
                 )
 
                 # Make the request
-                response = client.get_resource(request=request)
+                response = await client.get_resource(request=request)
 
                 # Handle the response
                 print(response)
@@ -354,7 +355,12 @@ class GatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -370,21 +376,21 @@ class GatewayServiceAsyncClient:
         r"""PostResource performs an HTTP POST on the Kubernetes
         API Server.
 
-
         .. code-block:: python
 
+            from google.api import httpbody_pb2  # type: ignore
             from google.cloud.gkeconnect import gateway_v1beta1
 
-            def sample_post_resource():
+            async def sample_post_resource():
                 # Create a client
-                client = gateway_v1beta1.GatewayServiceClient()
+                client = gateway_v1beta1.GatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
-                request = gateway_v1beta1.HttpBody(
+                request = httpbody_pb2.HttpBody(
                 )
 
                 # Make the request
-                response = client.post_resource(request=request)
+                response = await client.post_resource(request=request)
 
                 # Handle the response
                 print(response)
@@ -507,7 +513,12 @@ class GatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -523,21 +534,21 @@ class GatewayServiceAsyncClient:
         r"""DeleteResource performs an HTTP DELETE on the
         Kubernetes API Server.
 
-
         .. code-block:: python
 
+            from google.api import httpbody_pb2  # type: ignore
             from google.cloud.gkeconnect import gateway_v1beta1
 
-            def sample_delete_resource():
+            async def sample_delete_resource():
                 # Create a client
-                client = gateway_v1beta1.GatewayServiceClient()
+                client = gateway_v1beta1.GatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
-                request = gateway_v1beta1.HttpBody(
+                request = httpbody_pb2.HttpBody(
                 )
 
                 # Make the request
-                response = client.delete_resource(request=request)
+                response = await client.delete_resource(request=request)
 
                 # Handle the response
                 print(response)
@@ -660,7 +671,12 @@ class GatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -676,21 +692,21 @@ class GatewayServiceAsyncClient:
         r"""PutResource performs an HTTP PUT on the Kubernetes
         API Server.
 
-
         .. code-block:: python
 
+            from google.api import httpbody_pb2  # type: ignore
             from google.cloud.gkeconnect import gateway_v1beta1
 
-            def sample_put_resource():
+            async def sample_put_resource():
                 # Create a client
-                client = gateway_v1beta1.GatewayServiceClient()
+                client = gateway_v1beta1.GatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
-                request = gateway_v1beta1.HttpBody(
+                request = httpbody_pb2.HttpBody(
                 )
 
                 # Make the request
-                response = client.put_resource(request=request)
+                response = await client.put_resource(request=request)
 
                 # Handle the response
                 print(response)
@@ -813,7 +829,12 @@ class GatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -829,21 +850,21 @@ class GatewayServiceAsyncClient:
         r"""PatchResource performs an HTTP PATCH on the
         Kubernetes API Server.
 
-
         .. code-block:: python
 
+            from google.api import httpbody_pb2  # type: ignore
             from google.cloud.gkeconnect import gateway_v1beta1
 
-            def sample_patch_resource():
+            async def sample_patch_resource():
                 # Create a client
-                client = gateway_v1beta1.GatewayServiceClient()
+                client = gateway_v1beta1.GatewayServiceAsyncClient()
 
                 # Initialize request argument(s)
-                request = gateway_v1beta1.HttpBody(
+                request = httpbody_pb2.HttpBody(
                 )
 
                 # Make the request
-                response = client.patch_resource(request=request)
+                response = await client.patch_resource(request=request)
 
                 # Handle the response
                 print(response)
@@ -966,7 +987,12 @@ class GatewayServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
