@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,7 +36,8 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api import httpbody_pb2  # type: ignore
 from google.protobuf import any_pb2  # type: ignore
-from .transports.base import GatewayServiceTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, GatewayServiceTransport
 from .transports.grpc import GatewayServiceGrpcTransport
 from .transports.grpc_asyncio import GatewayServiceGrpcAsyncIOTransport
 
@@ -55,7 +56,10 @@ class GatewayServiceClientMeta(type):
     _transport_registry["grpc"] = GatewayServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = GatewayServiceGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[GatewayServiceTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[GatewayServiceTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -166,7 +170,9 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -179,9 +185,13 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -190,9 +200,13 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -201,9 +215,13 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -212,10 +230,14 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -400,9 +422,9 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         r"""GetResource performs an HTTP GET request on the
         Kubernetes API Server.
 
-
         .. code-block:: python
 
+            from google.api import httpbody_pb2  # type: ignore
             from google.cloud.gkeconnect import gateway_v1beta1
 
             def sample_get_resource():
@@ -410,7 +432,7 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
                 client = gateway_v1beta1.GatewayServiceClient()
 
                 # Initialize request argument(s)
-                request = gateway_v1beta1.HttpBody(
+                request = httpbody_pb2.HttpBody(
                 )
 
                 # Make the request
@@ -536,7 +558,12 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.get_resource]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -552,9 +579,9 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         r"""PostResource performs an HTTP POST on the Kubernetes
         API Server.
 
-
         .. code-block:: python
 
+            from google.api import httpbody_pb2  # type: ignore
             from google.cloud.gkeconnect import gateway_v1beta1
 
             def sample_post_resource():
@@ -562,7 +589,7 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
                 client = gateway_v1beta1.GatewayServiceClient()
 
                 # Initialize request argument(s)
-                request = gateway_v1beta1.HttpBody(
+                request = httpbody_pb2.HttpBody(
                 )
 
                 # Make the request
@@ -688,7 +715,12 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.post_resource]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -704,9 +736,9 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         r"""DeleteResource performs an HTTP DELETE on the
         Kubernetes API Server.
 
-
         .. code-block:: python
 
+            from google.api import httpbody_pb2  # type: ignore
             from google.cloud.gkeconnect import gateway_v1beta1
 
             def sample_delete_resource():
@@ -714,7 +746,7 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
                 client = gateway_v1beta1.GatewayServiceClient()
 
                 # Initialize request argument(s)
-                request = gateway_v1beta1.HttpBody(
+                request = httpbody_pb2.HttpBody(
                 )
 
                 # Make the request
@@ -840,7 +872,12 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.delete_resource]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -856,9 +893,9 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         r"""PutResource performs an HTTP PUT on the Kubernetes
         API Server.
 
-
         .. code-block:: python
 
+            from google.api import httpbody_pb2  # type: ignore
             from google.cloud.gkeconnect import gateway_v1beta1
 
             def sample_put_resource():
@@ -866,7 +903,7 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
                 client = gateway_v1beta1.GatewayServiceClient()
 
                 # Initialize request argument(s)
-                request = gateway_v1beta1.HttpBody(
+                request = httpbody_pb2.HttpBody(
                 )
 
                 # Make the request
@@ -992,7 +1029,12 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.put_resource]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1008,9 +1050,9 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         r"""PatchResource performs an HTTP PATCH on the
         Kubernetes API Server.
 
-
         .. code-block:: python
 
+            from google.api import httpbody_pb2  # type: ignore
             from google.cloud.gkeconnect import gateway_v1beta1
 
             def sample_patch_resource():
@@ -1018,7 +1060,7 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
                 client = gateway_v1beta1.GatewayServiceClient()
 
                 # Initialize request argument(s)
-                request = gateway_v1beta1.HttpBody(
+                request = httpbody_pb2.HttpBody(
                 )
 
                 # Make the request
@@ -1144,7 +1186,12 @@ class GatewayServiceClient(metaclass=GatewayServiceClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.patch_resource]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
