@@ -14,34 +14,35 @@
 # limitations under the License.
 #
 import os
-import mock
 
-import grpc
-from grpc.experimental import aio
+# try/except added for compatibility with python < 3.8
+try:
+    from unittest import mock
+    from unittest.mock import AsyncMock
+except ImportError:
+    import mock
+
 import math
-import pytest
-from proto.marshal.rules.dates import DurationRule, TimestampRule
-
 
 from google.api import httpbody_pb2  # type: ignore
+from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers
-from google.api_core import grpc_helpers_async
-from google.api_core import path_template
+import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
-from google.cloud.gkeconnect.gateway_v1beta1.services.gateway_service import (
-    GatewayServiceAsyncClient,
-)
-from google.cloud.gkeconnect.gateway_v1beta1.services.gateway_service import (
-    GatewayServiceClient,
-)
-from google.cloud.gkeconnect.gateway_v1beta1.services.gateway_service import transports
 from google.oauth2 import service_account
 from google.protobuf import any_pb2  # type: ignore
-import google.auth
+import grpc
+from grpc.experimental import aio
+from proto.marshal.rules.dates import DurationRule, TimestampRule
+import pytest
+
+from google.cloud.gkeconnect.gateway_v1beta1.services.gateway_service import (
+    GatewayServiceAsyncClient,
+    GatewayServiceClient,
+    transports,
+)
 
 
 def client_cert_source_callback():
@@ -89,20 +90,24 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [GatewayServiceClient, GatewayServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (GatewayServiceClient, "grpc"),
+        (GatewayServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_gateway_service_client_from_service_account_info(client_class):
+def test_gateway_service_client_from_service_account_info(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "connectgateway.googleapis.com:443"
+        assert client.transport._host == ("connectgateway.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -131,23 +136,31 @@ def test_gateway_service_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [GatewayServiceClient, GatewayServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (GatewayServiceClient, "grpc"),
+        (GatewayServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_gateway_service_client_from_service_account_file(client_class):
+def test_gateway_service_client_from_service_account_file(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "connectgateway.googleapis.com:443"
+        assert client.transport._host == ("connectgateway.googleapis.com:443")
 
 
 def test_gateway_service_client_get_transport_class():
@@ -495,7 +508,9 @@ def test_gateway_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -635,10 +650,17 @@ def test_gateway_service_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [httpbody_pb2.HttpBody, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        httpbody_pb2.HttpBody,
+        dict,
+    ],
+)
 def test_get_resource(request_type, transport: str = "grpc"):
     client = GatewayServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -649,7 +671,8 @@ def test_get_resource(request_type, transport: str = "grpc"):
     with mock.patch.object(type(client.transport.get_resource), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = httpbody_pb2.HttpBody(
-            content_type="content_type_value", data=b"data_blob",
+            content_type="content_type_value",
+            data=b"data_blob",
         )
         response = client.get_resource(request)
 
@@ -668,7 +691,8 @@ def test_get_resource_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = GatewayServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -684,7 +708,8 @@ async def test_get_resource_async(
     transport: str = "grpc_asyncio", request_type=httpbody_pb2.HttpBody
 ):
     client = GatewayServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -695,7 +720,10 @@ async def test_get_resource_async(
     with mock.patch.object(type(client.transport.get_resource), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            httpbody_pb2.HttpBody(content_type="content_type_value", data=b"data_blob",)
+            httpbody_pb2.HttpBody(
+                content_type="content_type_value",
+                data=b"data_blob",
+            )
         )
         response = await client.get_resource(request)
 
@@ -716,7 +744,9 @@ async def test_get_resource_async_from_dict():
 
 
 def test_get_resource_from_dict_foreign():
-    client = GatewayServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = GatewayServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.get_resource), "__call__") as call:
         # Designate an appropriate return value for the call.
@@ -731,10 +761,17 @@ def test_get_resource_from_dict_foreign():
         call.assert_called()
 
 
-@pytest.mark.parametrize("request_type", [httpbody_pb2.HttpBody, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        httpbody_pb2.HttpBody,
+        dict,
+    ],
+)
 def test_post_resource(request_type, transport: str = "grpc"):
     client = GatewayServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -745,7 +782,8 @@ def test_post_resource(request_type, transport: str = "grpc"):
     with mock.patch.object(type(client.transport.post_resource), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = httpbody_pb2.HttpBody(
-            content_type="content_type_value", data=b"data_blob",
+            content_type="content_type_value",
+            data=b"data_blob",
         )
         response = client.post_resource(request)
 
@@ -764,7 +802,8 @@ def test_post_resource_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = GatewayServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -780,7 +819,8 @@ async def test_post_resource_async(
     transport: str = "grpc_asyncio", request_type=httpbody_pb2.HttpBody
 ):
     client = GatewayServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -791,7 +831,10 @@ async def test_post_resource_async(
     with mock.patch.object(type(client.transport.post_resource), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            httpbody_pb2.HttpBody(content_type="content_type_value", data=b"data_blob",)
+            httpbody_pb2.HttpBody(
+                content_type="content_type_value",
+                data=b"data_blob",
+            )
         )
         response = await client.post_resource(request)
 
@@ -812,7 +855,9 @@ async def test_post_resource_async_from_dict():
 
 
 def test_post_resource_from_dict_foreign():
-    client = GatewayServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = GatewayServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.post_resource), "__call__") as call:
         # Designate an appropriate return value for the call.
@@ -827,10 +872,17 @@ def test_post_resource_from_dict_foreign():
         call.assert_called()
 
 
-@pytest.mark.parametrize("request_type", [httpbody_pb2.HttpBody, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        httpbody_pb2.HttpBody,
+        dict,
+    ],
+)
 def test_delete_resource(request_type, transport: str = "grpc"):
     client = GatewayServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -841,7 +893,8 @@ def test_delete_resource(request_type, transport: str = "grpc"):
     with mock.patch.object(type(client.transport.delete_resource), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = httpbody_pb2.HttpBody(
-            content_type="content_type_value", data=b"data_blob",
+            content_type="content_type_value",
+            data=b"data_blob",
         )
         response = client.delete_resource(request)
 
@@ -860,7 +913,8 @@ def test_delete_resource_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = GatewayServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -876,7 +930,8 @@ async def test_delete_resource_async(
     transport: str = "grpc_asyncio", request_type=httpbody_pb2.HttpBody
 ):
     client = GatewayServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -887,7 +942,10 @@ async def test_delete_resource_async(
     with mock.patch.object(type(client.transport.delete_resource), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            httpbody_pb2.HttpBody(content_type="content_type_value", data=b"data_blob",)
+            httpbody_pb2.HttpBody(
+                content_type="content_type_value",
+                data=b"data_blob",
+            )
         )
         response = await client.delete_resource(request)
 
@@ -908,7 +966,9 @@ async def test_delete_resource_async_from_dict():
 
 
 def test_delete_resource_from_dict_foreign():
-    client = GatewayServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = GatewayServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.delete_resource), "__call__") as call:
         # Designate an appropriate return value for the call.
@@ -923,10 +983,17 @@ def test_delete_resource_from_dict_foreign():
         call.assert_called()
 
 
-@pytest.mark.parametrize("request_type", [httpbody_pb2.HttpBody, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        httpbody_pb2.HttpBody,
+        dict,
+    ],
+)
 def test_put_resource(request_type, transport: str = "grpc"):
     client = GatewayServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -937,7 +1004,8 @@ def test_put_resource(request_type, transport: str = "grpc"):
     with mock.patch.object(type(client.transport.put_resource), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = httpbody_pb2.HttpBody(
-            content_type="content_type_value", data=b"data_blob",
+            content_type="content_type_value",
+            data=b"data_blob",
         )
         response = client.put_resource(request)
 
@@ -956,7 +1024,8 @@ def test_put_resource_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = GatewayServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -972,7 +1041,8 @@ async def test_put_resource_async(
     transport: str = "grpc_asyncio", request_type=httpbody_pb2.HttpBody
 ):
     client = GatewayServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -983,7 +1053,10 @@ async def test_put_resource_async(
     with mock.patch.object(type(client.transport.put_resource), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            httpbody_pb2.HttpBody(content_type="content_type_value", data=b"data_blob",)
+            httpbody_pb2.HttpBody(
+                content_type="content_type_value",
+                data=b"data_blob",
+            )
         )
         response = await client.put_resource(request)
 
@@ -1004,7 +1077,9 @@ async def test_put_resource_async_from_dict():
 
 
 def test_put_resource_from_dict_foreign():
-    client = GatewayServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = GatewayServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.put_resource), "__call__") as call:
         # Designate an appropriate return value for the call.
@@ -1019,10 +1094,17 @@ def test_put_resource_from_dict_foreign():
         call.assert_called()
 
 
-@pytest.mark.parametrize("request_type", [httpbody_pb2.HttpBody, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        httpbody_pb2.HttpBody,
+        dict,
+    ],
+)
 def test_patch_resource(request_type, transport: str = "grpc"):
     client = GatewayServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1033,7 +1115,8 @@ def test_patch_resource(request_type, transport: str = "grpc"):
     with mock.patch.object(type(client.transport.patch_resource), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = httpbody_pb2.HttpBody(
-            content_type="content_type_value", data=b"data_blob",
+            content_type="content_type_value",
+            data=b"data_blob",
         )
         response = client.patch_resource(request)
 
@@ -1052,7 +1135,8 @@ def test_patch_resource_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = GatewayServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1068,7 +1152,8 @@ async def test_patch_resource_async(
     transport: str = "grpc_asyncio", request_type=httpbody_pb2.HttpBody
 ):
     client = GatewayServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1079,7 +1164,10 @@ async def test_patch_resource_async(
     with mock.patch.object(type(client.transport.patch_resource), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            httpbody_pb2.HttpBody(content_type="content_type_value", data=b"data_blob",)
+            httpbody_pb2.HttpBody(
+                content_type="content_type_value",
+                data=b"data_blob",
+            )
         )
         response = await client.patch_resource(request)
 
@@ -1100,7 +1188,9 @@ async def test_patch_resource_async_from_dict():
 
 
 def test_patch_resource_from_dict_foreign():
-    client = GatewayServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = GatewayServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.patch_resource), "__call__") as call:
         # Designate an appropriate return value for the call.
@@ -1122,7 +1212,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = GatewayServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1142,7 +1233,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = GatewayServiceClient(client_options=options, transport=transport,)
+        client = GatewayServiceClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -1158,7 +1252,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = GatewayServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1201,10 +1296,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = GatewayServiceClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = GatewayServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.GatewayServiceGrpcTransport,)
+    client = GatewayServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.GatewayServiceGrpcTransport,
+    )
 
 
 def test_gateway_service_base_transport_error():
@@ -1242,6 +1355,14 @@ def test_gateway_service_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_gateway_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1253,7 +1374,8 @@ def test_gateway_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.GatewayServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1386,24 +1508,40 @@ def test_gateway_service_grpc_transport_client_cert_source_for_mtls(transport_cl
             )
 
 
-def test_gateway_service_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_gateway_service_host_no_port(transport_name):
     client = GatewayServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="connectgateway.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "connectgateway.googleapis.com:443"
+    assert client.transport._host == ("connectgateway.googleapis.com:443")
 
 
-def test_gateway_service_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_gateway_service_host_with_port(transport_name):
     client = GatewayServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="connectgateway.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "connectgateway.googleapis.com:8000"
+    assert client.transport._host == ("connectgateway.googleapis.com:8000")
 
 
 def test_gateway_service_grpc_transport_channel():
@@ -1411,7 +1549,8 @@ def test_gateway_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.GatewayServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1423,7 +1562,8 @@ def test_gateway_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.GatewayServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1552,7 +1692,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = GatewayServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1570,7 +1712,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = GatewayServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1588,7 +1732,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = GatewayServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1608,7 +1754,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = GatewayServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1633,7 +1780,8 @@ def test_client_with_default_client_info():
         transports.GatewayServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = GatewayServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1642,7 +1790,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = GatewayServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1650,7 +1799,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = GatewayServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
